@@ -6,18 +6,16 @@ import (
 	"os"
 	"strings"
 
+	"github.com/aquasecurity/defsec/pkg/formatters"
+	"github.com/aquasecurity/defsec/pkg/providers"
+	"github.com/aquasecurity/defsec/pkg/scan"
+	scanner "github.com/aquasecurity/defsec/pkg/scanners/terraform"
 	"github.com/aquasecurity/tfsec/internal/pkg/formatter"
-
-	scanner "github.com/aquasecurity/defsec/scanners/terraform"
-
-	"github.com/aquasecurity/defsec/formatters"
-	"github.com/aquasecurity/defsec/providers"
-	"github.com/aquasecurity/defsec/rules"
 	"github.com/aquasecurity/tfsec/version"
 	"github.com/liamg/tml"
 )
 
-func output(baseFilename string, formats []string, dir string, results []rules.Result, metrics scanner.Metrics) error {
+func output(baseFilename string, formats []string, dir string, results []scan.Result, metrics scanner.Metrics) error {
 	if baseFilename == "" && len(formats) > 1 {
 		return fmt.Errorf("you must specify a base output filename with --out if you want to use multiple formats")
 	}
@@ -38,7 +36,7 @@ func output(baseFilename string, formats []string, dir string, results []rules.R
 	return nil
 }
 
-func gatherLinks(result rules.Result) []string {
+func gatherLinks(result scan.Result) []string {
 	v := "latest"
 	if version.Version != "" {
 		v = version.Version
@@ -66,7 +64,7 @@ func gatherLinks(result rules.Result) []string {
 	return append(docsLink, links...)
 }
 
-func outputFormat(addExtension bool, baseFilename string, format string, dir string, results []rules.Result, metrics scanner.Metrics) (string, error) {
+func outputFormat(addExtension bool, baseFilename string, format string, dir string, results scan.Results, metrics scanner.Metrics) (string, error) {
 
 	factory := formatters.New().
 		WithDebugEnabled(debug).
@@ -79,22 +77,28 @@ func outputFormat(addExtension bool, baseFilename string, format string, dir str
 		WithIncludePassed(includePassed)
 
 	var alsoStdout bool
+	var makeRelative bool
 
 	switch strings.ToLower(format) {
 	case "", "default":
 		alsoStdout = true
 		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput))
 	case "json":
+		makeRelative = true
 		factory.AsJSON()
 	case "csv":
+		makeRelative = true
 		factory.AsCSV()
 	case "checkstyle":
+		makeRelative = true
 		factory.AsCheckStyle()
 	case "junit":
+		makeRelative = true
 		factory.AsJUnit()
 	case "text":
 		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput)).WithColoursEnabled(false)
 	case "sarif":
+		makeRelative = true
 		factory.AsSARIF()
 	case "gif":
 		factory.WithCustomFormatterFunc(formatter.GifWithMetrics(metrics))
@@ -102,6 +106,10 @@ func outputFormat(addExtension bool, baseFilename string, format string, dir str
 		return "", fmt.Errorf("invalid format specified: '%s'", format)
 	}
 
+	if makeRelative {
+		results.SetRelativeTo(dir)
+	}
+
 	var outputPath string
 	if baseFilename != "" {
 		if addExtension {
